@@ -104,8 +104,8 @@ test_that("n1CDF", {
     #save(r_lba1, A, b, t0, v1, v2, file = "n1CDF_no_diff_example_5.RData")
     
     expect_equal(
-      n1CDF(r_lba1[,"rt"][r_lba1[,"response"]==1], A=A, b=b, t0 = t0, mean_v=v1[1:2], sd_v=v2[1]), 
-      .n1CDF(pmax(r_lba1[,"rt"][r_lba1[,"response"]==1]-t0[1], 0), x0max=A, chi=b, drift=v1[1:2], sdI=v2[1])
+      n1CDF(sort(r_lba1[,"rt"][r_lba1[,"response"]==1]), A=A, b=b, t0 = t0, mean_v=v1[1:2], sd_v=v2[1]), 
+      .n1CDF(sort(pmax(r_lba1[,"rt"][r_lba1[,"response"]==1]-t0[1], 0)), x0max=A, chi=b, drift=v1[1:2], sdI=v2[1]), tolerance = 0.0001
     )
     
   }
